<?php
/**
 * De Minimalist functions and definitions
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are instead attached
 * to a filter or action hook. The hook can be removed by using remove_action() or
 * remove_filter() and you can attach your own function to the hook.
 *
 * For more information on hooks, actions, and filters, see http://codex.wordpress.org/Plugin_API.
 *
 * === Index Functions ===
 * de_minimalist_setup()
 * my_scripts_method()
 * Set a default theme color array for WP.com
 * de_minimalist_page_menu_args()
 * de_minimalist_widgets_init()
 * de_minimalist_content_nav()
 * kriesi_pagination()
 * de_minimalist_comment()
 * realodix_comment_form()
 * de_minimalist_posted_on()
 * de_minimalist_body_classes()
 * de_minimalist_categorized_blog()
 * de_minimalist_category_transient_flusher()
 *
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) )
	$content_width = 640; /* pixels */

if ( ! function_exists( 'de_minimalist_setup' ) ):
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 * To override de_minimalist_setup() in a child theme, add your own de_minimalist_setup to your child theme's
 * functions.php file.
 */
function de_minimalist_setup() {
	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 * If you're building a theme based on de_minimalist, use a find and replace
	 * to change 'de_minimalist' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'de_minimalist', get_template_directory() . '/languages' );

	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links' );

	/**
	 * This theme uses wp_nav_menu() in one location.
	 */
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'de_minimalist' ),
	) );

	/**
	 * Add support for the Aside and Gallery Post Formats
	 */
	add_theme_support( 'post-formats', array( 'aside', 'image', 'gallery' ) );

	// Add support for post thumbnails.
	add_theme_support( 'post-thumbnails' );
}
endif; // de_minimalist_setup

/**
 * Tell WordPress to run de_minimalist_setup() when the 'after_setup_theme' hook is run.
 */
add_action( 'after_setup_theme', 'de_minimalist_setup' );


/**
* Function Reference/wp enqueue script
* The safe and recommended method of adding JavaScript to a WordPress generated page
* is by using `wp_enqueue_script()`. This function includes the script if it hasn't
* already been included, and safely handles dependencies.
*/
// Run jQuery
function my_scripts_method() {
	wp_enqueue_script( 'jquery' );
}

add_action('wp_enqueue_scripts', 'my_scripts_method');


/**
 * Set a default theme color array for WP.com.
 */
$theme_colors = array(
	'bg' => 'ffffff',
	'border' => 'eeeeee',
	'text' => '444444',
);

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 */
function de_minimalist_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'de_minimalist_page_menu_args' );

/**
 * Register widgetized area and update sidebar with default widgets
 */
function de_minimalist_widgets_init() {
	register_sidebar( array(
		'name' => __( 'Sidebar 1', 'de_minimalist' ),
		'id' => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );

	register_sidebar( array(
		'name' => __( 'Sidebar 2', 'de_minimalist' ),
		'id' => 'sidebar-2',
		'description' => __( 'An optional second sidebar area', 'de_minimalist' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );
}
add_action( 'init', 'de_minimalist_widgets_init' );


/**
 * Display navigation to next/previous pages when applicable
 *
 */
if ( ! function_exists( 'de_minimalist_content_nav' ) ):

function de_minimalist_content_nav( $nav_id ) {
	global $wp_query;

	?>
	<nav id="<?php echo $nav_id; ?>">
		<h1 class="assistive-text section-heading"><?php _e( 'Post navigation', 'de_minimalist' ); ?></h1>

	<?php if ( is_single() ) : // navigation links for single posts ?>

		<?php previous_post_link( '<div class="nav-previous">%link</div>', '<span class="meta-nav">' . _x( '&larr;', 'Previous post link', 'de_minimalist' ) . '</span> %title' ); ?>
		<?php next_post_link( '<div class="nav-next">%link</div>', '%title <span class="meta-nav">' . _x( '&rarr;', 'Next post link', 'de_minimalist' ) . '</span>' ); ?>

	<?php elseif ( $wp_query->max_num_pages > 1 && ( is_home() || is_archive() || is_search() ) ) : // navigation links for home, archive, and search pages ?>

		<?php if ( get_next_posts_link() ) : ?>
		<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'de_minimalist' ) ); ?></div>
		<?php endif; ?>

		<?php if ( get_previous_posts_link() ) : ?>
		<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'de_minimalist' ) ); ?></div>
		<?php endif; ?>

	<?php endif; ?>

	</nav> <?php // end of echo $nav_id; ?>
	<?php
}
endif; // de_minimalist_content_nav


/*******************/
/* PAGE NAVIGATION */
/*
 * Put <?php kriesi_pagination();?> in index.php
 *
 * @since De Minimalist 2.0
 */

/*As you can see we got 2 optional parameters to pass:
The first one is the number of pages: passing this is only necessary if you are using a
custom loop, something I will explain a little bit later.

The second parameter sets the number of links to display. Range tells the script how many
links before and after the current page should be displayed before it only shows the small 
arrows. For example with the default range of 2, if you are currently visiting the first 
page the script would display the 2 following pages, the next page button and the last page 
button.

if we would visit page number 4 the script would show page 4 as the current page, would 
directly link to page 2 and 3 as well to 5 and 6. All other would be hidden:*/
function kriesi_pagination($pages = '', $range = 2){

/*For easier arithmetic operations afterwards we also store the max number of items to 
display in a separate variable:*/
$showitems = ($range * 2)+1;  

/*Next we need access to the global variable $paged. WordPress uses this variable to 
store which page we are currently viewing. If that variable is empty we set it to 1. 
Why do we need to know it? The page we are currently at should not be linked, it 
should be displayed as active.*/
     global $paged;
     if(empty($paged)) $paged = 1;

     if($pages == '')
     {
         global $wp_query;
         $pages = $wp_query->max_num_pages;
         if(!$pages)
         {
             $pages = 1;
         }
     }   

/*In this section, we begin to insert into HTML.*/
     if(1 != $pages)
     {
         echo "<div class='pagination'>";
         if($paged > 2 && $paged > $range+1 && $showitems < $pages) echo "<a href='".get_pagenum_link(1)."' title='Go to Home Page'>&laquo;</a>";
         if($paged > 1 && $showitems < $pages) echo "<a href='".get_pagenum_link($paged - 1)."' title='Previous'>&lsaquo;</a>";

         for ($i=1; $i <= $pages; $i++)
         {
             if (1 != $pages &&( !($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems ))
             {
                 echo ($paged == $i)? "<span class='current'>".$i."</span>":"<a href='".get_pagenum_link($i)."' class='inactive' >".$i."</a>";
             }
         }

         if ($paged < $pages && $showitems < $pages) echo "<a href='".get_pagenum_link($paged + 1)."' title='Next'>&rsaquo;</a>";  
         if ($paged < $pages-1 &&  $paged+$range-1 < $pages && $showitems < $pages) 
		 echo "<a href='".get_pagenum_link($pages)."' title='Go to Last Page'>&raquo;</a>";
         echo "</div>\n";
     }
}


/**
 * META TAG
 *
 * Fungsi untuk menampilkan TAG pada halaman post.
 *
 * @since De Minimalist 2.1
 * @date 16/04/2012
 */
function realodix_tag() {
the_tags(
	'<span class="realodix_tag"> <img src="'. 
	get_template_directory_uri()
	.'/images/tag_orange.png" height="18" width="18"> ', __( ', ', 'de_minimalist' ));
}


if ( ! function_exists( 'de_minimalist_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * To override this walker in a child theme without modifying the comments template
 * simply create your own de_minimalist_comment(), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 */
function de_minimalist_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'de_minimalist' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( '(Edit)', 'de_minimalist' ), ' ' ); ?></p>
	<?php
			break;
		default :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment">
			<footer>
				<div class="comment-author vcard">
					<?php echo get_avatar( $comment, 40 ); ?>
					<?php printf( __( '%s <span class="says">says:</span>', 'de_minimalist' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>
				</div><!-- .comment-author .vcard -->
				<?php if ( $comment->comment_approved == '0' ) : ?>
					<em id="comment_waiting_moderation"><?php _e( 'Your comment is awaiting moderation.', 'de_minimalist' ); ?></em>
					<br />
				<?php endif; ?>

				<div class="comment-meta commentmetadata">
					<time pubdate datetime="<?php comment_time( 'c' ); ?>">
					<?php
					/* translators: 1: date, 2: time */
					printf( __( '%1$s at %2$s', 'de_minimalist' ), get_comment_date(), get_comment_time() ); ?>
					</time>
				</div><!-- .comment-meta .commentmetadata -->
			</footer>

			<div class="comment-content"><?php comment_text(); ?></div>

			<div class="comment_reply_link">
				<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</div><!-- .reply -->

			<div class="edit_comment_link">
			<?php edit_comment_link( __( 'Edit', 'de_minimalist' ), ' ' );?>
			</div>

			<div id="clear_both">	</div>
		</article><!-- #comment-## -->

	<?php
			break;
	endswitch;
}
endif; // ends check for de_minimalist_comment()


/**
 * Prints HTML with meta information for the current post-date/time and author.
 * Create your own de_minimalist_posted_on to override in a child theme
 *
 */
if ( ! function_exists( 'de_minimalist_posted_on' ) ) :
function de_minimalist_posted_on() {
	printf( __( '<span class="sep">Posted on </span><a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s" pubdate>%4$s</time></a><span class="byline"> <span class="sep"> by </span> <span class="author vcard"><a class="url fn n" href="%5$s" title="%6$s" rel="author">%7$s</a></span></span>', 'de_minimalist' ),
		esc_url( get_permalink() ),
		esc_attr( get_the_time() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_attr( sprintf( __( 'View all posts by %s', 'de_minimalist' ), get_the_author() ) ),
		esc_html( get_the_author() )
	);
}
endif;

/**
 * Adds custom classes to the array of body classes.
 *
 */
function de_minimalist_body_classes( $classes ) {
	// Adds a class of single-author to blogs with only 1 published author
	if ( ! is_multi_author() ) {
		$classes[] = 'single-author';
	}

	return $classes;
}
add_filter( 'body_class', 'de_minimalist_body_classes' );

/**
 * Returns true if a blog has more than 1 category
 *
 */
function de_minimalist_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'all_the_cool_cats' ) ) ) {
		// Create an array of all the categories that are attached to posts
		$all_the_cool_cats = get_categories( array(
			'hide_empty' => 1,
		) );

		// Count the number of categories that are attached to the posts
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'all_the_cool_cats', $all_the_cool_cats );
	}

	if ( '1' != $all_the_cool_cats ) {
		// This blog has more than 1 category so de_minimalist_categorized_blog should return true
		return true;
	} else {
		// This blog has only 1 category so de_minimalist_categorized_blog should return false
		return false;
	}
}

/**
 * Flush out the transients used in de_minimalist_categorized_blog
 *
 */
function de_minimalist_category_transient_flusher() {
	// Like, beat it. Dig?
	delete_transient( 'all_the_cool_cats' );
}
add_action( 'edit_category', 'de_minimalist_category_transient_flusher' );
add_action( 'save_post', 'de_minimalist_category_transient_flusher' );

/**
 * Filter in a link to a content ID attribute for the next/previous image links on image attachment pages
 *
 */
function de_minimalist_enhanced_image_navigation( $url, $id ) {
    if ( ! is_attachment() && ! wp_attachment_is_image( $id ) )
        return $url;

    $image = get_post( $id );
    if ( $image->post_parent && $image->post_parent != $id )
        $url .= '#main';

    return $url;
}
add_filter( 'attachment_link', 'de_minimalist_enhanced_image_navigation', 10, 2 );

/**
 * This theme was built with PHP, Semantic HTML, CSS, love, and a Toolbox.
 */